@@ -1,11 +1,11 @@
 /* AstroPrincipal.m
  * Commander of the Astrology module
  *
- * Copyright (C) 2003-2006 by vhf interservice GmbH
+ * Copyright (C) 2003-2007 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2006-07-15
+ * modified: 2007-07-22
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -114,15 +114,16 @@ NSString *stringFromDeg(float deg)
 
 
 /* init
- * modified: 2006-07-15
+ * modified: 2006-07-19
  */
 - init
 {   NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
     NSFileManager		*fileManager = [NSFileManager defaultManager];
 #if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     NSMenu			*toolMenu = [[[NSApp mainMenu] itemWithTag:MENU_TOOLS] target];
-#else
+#else	// Apple, GNUstep
     NSMenu			*toolMenu = [[[NSApp mainMenu] itemAtIndex:MENU_TOOLS-1] submenu];
+    NSMenu			*helpMenu = [[[NSApp mainMenu] itemAtIndex:MENU_HELP -1] submenu];
 #endif
 
     /* create HOME-Library entries, if they doesn't exist */
@@ -186,6 +187,14 @@ NSString *stringFromDeg(float deg)
     if (Prefs_ShowAstroPanel)
         [self showAstroPanel:self];
 
+    /* add a menu for our documentation */
+#ifdef __APPLE__
+    [helpMenu addItemWithTitle:@"Cenon Astro"
+                        action:@selector(showAstroHelp:)
+                 keyEquivalent:@""];
+    [[[helpMenu itemArray] objectAtIndex:[[helpMenu itemArray] count]-1] setTarget:self];
+#endif
+
     /* create event manager, city manager, time zone manager */
     eventManager    = [EventManager new];
     cityManager     = [CityManager new];
@@ -223,6 +232,48 @@ NSString *stringFromDeg(float deg)
     return astroPanel;
 }
 
+/* load PDF documentation
+ * Note: each module can add a help menu entry to load it's docu
+ * modified: 2007-07-19
+ */
+- (void)showAstroHelp:sender
+{
+#if defined(GNUSTEP_BASE_VERSION) || defined(__APPLE__)	// GNUstep or Apple
+    NSBundle	*bundle = [NSBundle bundleForClass:[AstroPrincipal class]];
+    NSArray     *localizations;
+    NSString    *locale, *path, *helpFile;
+    int         l, i;
+    
+    localizations = [NSBundle preferredLocalizationsFromArray:[bundle localizations]];
+    for (l=0; l<[localizations count]; l++ )
+    {
+        locale = [[localizations objectAtIndex:l] stringByAppendingString:@".lproj"];
+        for (i=0; i<3; i++)
+        {
+            switch (i)
+            {
+                case 0: path = [bundle resourcePath];
+                    helpFile = vhfPathWithPathComponents(path, locale, DOCU_ASTRO, nil);
+                    break;
+                case 1: path = vhfUserLibrary(APPNAME);
+                    helpFile = vhfPathWithPathComponents(path, @"Docu", locale, DOCU_ASTRO, nil);
+                    break;
+                case 2: path = vhfLocalLibrary(APPNAME);
+                    helpFile = vhfPathWithPathComponents(path, @"Docu", locale, DOCU_ASTRO, nil);
+                    break;
+                default:
+                    return;
+            }
+            if ( [[NSFileManager defaultManager] fileExistsAtPath:helpFile] )
+            {   [[NSWorkspace sharedWorkspace] openFile:helpFile];
+                l = [localizations count];
+                break;
+            }
+        }
+    }
+#endif
+}
+
 - eventManager		{ return eventManager; }
 - cityManager		{ return cityManager; }
 - timeZoneManager	{ return timeZoneManager; }
