@@ -5,7 +5,7 @@
  * Rewritten from mapreader.c created by Steve Putz, 22-Aug-90
  *
  * created:  2001-07-30
- * modified: 2006-04-08 (Azimut projection added)
+ * modified: 2006-06-12 (LITTLE_ENDIAN)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -1696,41 +1696,41 @@ long changeBitDir16(int intVal)
 
     if (ms->proj && ms->proj < PROJ_MERCATOR)
     {
-	/* find maximum longitude ranges in projected area (in seconds) */
-	long absN = abs(clipNSec);
-	long absS = abs(clipSSec);
-	long maxNS = absN > absS ? absN : absS;
-	long minNS;
-	if (clipNSec >= 0 && clipSSec <= 0) minNS = 0;
-	else minNS = absN < absS ? absN : absS;
-	if (clipWSec >= 0)	// use W longitude at minNS
+        /* find maximum longitude ranges in projected area (in seconds) */
+        long absN = abs(clipNSec);
+        long absS = abs(clipSSec);
+        long maxNS = absN > absS ? absN : absS;
+        long minNS;
+        if (clipNSec >= 0 && clipSSec <= 0) minNS = 0;
+        else minNS = absN < absS ? absN : absS;
+        if (clipWSec >= 0)	// use W longitude at minNS
         {
-	    if (minNS >= DEG90_SECS)
+            if (minNS >= DEG90_SECS)
                 clipWSec = -DEG180_SECS;
-	    else
+            else
                 clipWSec = XPROJ_DIV(clipWSec, XPROJ_SEC(XProj, minNS));
-	}
+            }
         else			// use W longitude at maxNS
         {
-	    if (maxNS >= DEG90_SECS)
+            if (maxNS >= DEG90_SECS)
                 clipWSec = -DEG180_SECS;
-	    else
+            else
                 clipWSec = -XPROJ_DIV(-clipWSec, XPROJ_SEC(XProj, maxNS));
-	}
-	if (clipESec >= 0)	// use E longitude at maxNS
+            }
+        if (clipESec >= 0)	// use E longitude at maxNS
         {
-	    if (maxNS >= DEG90_SECS)
+            if (maxNS >= DEG90_SECS)
                 clipESec = DEG180_SECS;
-	    else
+            else
                 clipESec = XPROJ_DIV(clipESec, XPROJ_SEC(XProj, maxNS));
-	}
+            }
         else			// use E longitude at minNS
         {
-	    if (minNS >= DEG90_SECS)
+            if (minNS >= DEG90_SECS)
                 clipESec = DEG180_SECS;
-	    else
+            else
                 clipESec = -XPROJ_DIV(-clipESec, XPROJ_SEC(XProj, minNS));
-	}
+            }
     }
     if (clipESec > DEG180_SECS)
         clipESec = DEG180_SECS;
@@ -1739,12 +1739,12 @@ long changeBitDir16(int intVal)
 
     if (mapIndex < 0 || mapIndex >= ms->mCount)
     {
-	[self drawGraticule:offsetEU :offsetNU :clipWSec :clipNSec :clipESec :clipSSec :seglist];
+        [self drawGraticule:offsetEU :offsetNU :clipWSec :clipNSec :clipESec :clipSSec :seglist];
         if ( drawZodiac )
             [self drawZodiacLines:offsetEU :offsetNU :clipWSec :clipNSec :clipESec :clipSSec :seglist];
         if ( drawDestiny )
             [self drawDestinyLines:offsetEU :offsetNU :clipWSec :clipNSec :clipESec :clipSSec :seglist];
-	return;
+        return;
     }
 
     map = &ms->maps[mapIndex];
@@ -1757,8 +1757,8 @@ long changeBitDir16(int intVal)
     map->muPerDot = SEC_TO_U(map, ms->msecPerDot);	/* cache this */
     if (map->muPerDot <= 0)
     {
-	fprintf(stderr, "map resolution exceeded, expect rounding errors\n");
-	map->muPerDot = 1;
+        fprintf(stderr, "map resolution exceeded, expect rounding errors\n");
+        map->muPerDot = 1;
     }
     /* normalize frame coordinates back to Greenwich */
     normWU = ( clipWSec < 0 ) ? (-SEC_TO_U(map,-clipWSec)) : (SEC_TO_U(map,clipWSec));
@@ -1767,14 +1767,14 @@ long changeBitDir16(int intVal)
     //if (clipESec != DEG180_SECS || clipWSec != -DEG180_SECS)	// original
     if (clipESec != DEG_TO_SEC(ms->maxLng) || clipWSec != -DEG_TO_SEC(ms->maxLng))	// georg 2003-07-11
     {
-	NORMALIZE_LONGITUDE(normWU, -map->cntrLngU, DEG180_U(map));
-	NORMALIZE_LONGITUDE(normEU, -map->cntrLngU, DEG180_U(map));
+        NORMALIZE_LONGITUDE(normWU, -map->cntrLngU, DEG180_U(map));
+        NORMALIZE_LONGITUDE(normEU, -map->cntrLngU, DEG180_U(map));
     }
     /* check if frame crosses +/-180 */
     if (normWU > normEU)
     {
-	if (map->minWSec > U_TO_SEC(map,normEU) && map->maxESec < U_TO_SEC(map,normWU))
-	    return;
+        if (map->minWSec > U_TO_SEC(map,normEU) && map->maxESec < U_TO_SEC(map,normWU))
+            return;
     }
     else if (map->minWSec > U_TO_SEC(map,normEU) || map->maxESec < U_TO_SEC(map,normWU))
         return;
@@ -1788,19 +1788,19 @@ long changeBitDir16(int intVal)
     fseek(map->mfile->file, map->mfile->header.dictaddr, 0);
     if (ms->dictbuf != NULL && ms->dictbuf_len < map->mfile->header.segcount)
     {
-	free(ms->dictbuf);
-	ms->dictbuf_len = 0;
-	ms->dictbuf = NULL;
+        free(ms->dictbuf);
+        ms->dictbuf_len = 0;
+        ms->dictbuf = NULL;
     }
     if (ms->dictbuf == NULL)
     {
-	ms->dictbuf = (struct segdict *)malloc(ms->max_segcount * sizeof(struct segdict));
-	if (ms->dictbuf == NULL)
+        ms->dictbuf = (struct segdict *)malloc(ms->max_segcount * sizeof(struct segdict));
+        if (ms->dictbuf == NULL)
         {
-	    fprintf(stderr, "%s: out of memory\n", Pgm);
-	    return;
-	}
-	ms->dictbuf_len = ms->max_segcount;
+            fprintf(stderr, "%s: out of memory\n", Pgm);
+            return;
+        }
+        ms->dictbuf_len = ms->max_segcount;
     }
     seglist -> line_width = -1;			/* get new values below */
     if (map->muPerDot < ms->fatten_thresh)
@@ -1809,7 +1809,7 @@ long changeBitDir16(int intVal)
     nItems = fread(ms->dictbuf, sizeof(struct segdict), map->mfile->header.segcount, map->mfile->file);
     for (dictptr = ms->dictbuf; nItems-- > 0; dictptr++)
     {
-#ifdef __LITTLE_ENDIAN__
+#if BYTE_ORDER == LITTLE_ENDIAN
         segid = changeBitDir32(dictptr->segid);
         nU = changeBitDir32(dictptr->maxlat);
         sU = changeBitDir32(dictptr->minlat);
